##INLA-SPDE kriging code
##TOAR database available for download at: https://doi.org/10.1594/PANGAEA.876108
##Last assess: 28 Feb 2019
##Illustation was made for 2008 
##this script needs to be manually changed/adopted for different year
##6-month running mean was ran through from January 2008 to March 2009
##(summer at southern hemisphere ends around March)
##Citation: Chang, K.-L., Cooper, O.R., West, J.J., Serre, M.L., Schultz, M.G.,
##Lin, M., Marécal, V., Josse, B., Deushi, M., Sudo, K., Liu, J., and Keller, C.A.:
##A new method (M3Fusion v1) for combining observations and multiple model output
##for an improved estimate of the global surface ozone distribution,
##Geosci. Model Dev., 2019.

col=c(rgb(0.2081, 0.1663, 0.5292),
rgb(0.3961, 0.3176, 0.8000),
rgb(0.0123, 0.4213, 0.8802),
rgb(0.4941, 0.7647, 0.8980),
rgb(0.1157, 0.7022, 0.6843),
rgb(0.5216, 0.6980, 0.1725),
rgb(0.9968, 0.7513, 0.2325),
rgb(1.0000, 0.4863, 0.0000),
rgb(0.8000, 0.3176, 0.3176),
rgb(0.6980, 0.1725, 0.1725))
N=10
library(INLA)
library(fields)
library(mgcv)
library(rworldmap)
library(rgeos)
library(maptools)
library(cleangeo)  ## For clgeo_Clean()
sPDF = getMap()
sPDF = clgeo_Clean(sPDF)  ## Needed to fix up some non-closed polygons
cont =
sapply(levels(sPDF$continent),
FUN = function(i) {
    ## Merge polygons within a continent
    poly = gUnionCascaded(subset(sPDF, continent==i))
    ## Give each polygon a unique ID
    poly = spChFIDs(poly, i)
    ## Make SPDF from SpatialPolygons object
    SpatialPolygonsDataFrame(poly,
    data.frame(continent=i, row.names=i))
},
USE.NAMES=TRUE)

## Bind the 6 continent-level SPDFs into a single SPDF
cont = Reduce(spRbind, cont)

############################################################
##Set-up ends
############################################################

strs <- readLines("SET2_monthly_global_2005-2009.csv")
dataset <- read.csv(text=strs, header=T, sep=";", skip=1, quote = "", fill=T)

annmean = dataset
annmean$time=as.numeric(unlist(annmean$datetime))
annmean =annmean[annmean$dma8epax>=-990.000000,]
annmean=na.omit(annmean)

dt1=annmean[annmean$datetime=="2008-01-01 00:00",]
dt2=annmean[annmean$datetime=="2008-02-01 00:00",]
dt3=annmean[annmean$datetime=="2008-03-01 00:00",]
dt4=annmean[annmean$datetime=="2008-04-01 00:00",]
dt5=annmean[annmean$datetime=="2008-05-01 00:00",]
dt6=annmean[annmean$datetime=="2008-06-01 00:00",]
dt7=annmean[annmean$datetime=="2008-07-01 00:00",]
dt8=annmean[annmean$datetime=="2008-08-01 00:00",]
dt9=annmean[annmean$datetime=="2008-09-01 00:00",]
dt10=annmean[annmean$datetime=="2008-10-01 00:00",]
dt11=annmean[annmean$datetime=="2008-11-01 00:00",]
dt12=annmean[annmean$datetime=="2008-12-01 00:00",]
dt13=annmean[annmean$datetime=="2009-01-01 00:00",]
dt14=annmean[annmean$datetime=="2009-02-01 00:00",]
dt15=annmean[annmean$datetime=="2009-03-01 00:00",]
dt=rbind(dt1,dt2,dt3,dt4,dt5,dt6,dt7,dt8,dt9,dt10,dt11,dt12, dt13,dt14,dt15)
dt$id= as.numeric(factor(dt$numid))

result=matrix(0, nrow=length(unique(dt$id)), ncol=4) 
for (i in 1:length(unique(dt$id))){
	sdt=dt[dt$id==i,]
	max=ifelse(nrow(sdt)>=10, max(rowMeans(embed(sdt$dma8epax,6)), na.rm=T), NA)
	result[i,]=c(sdt$station_id[1], sdt$station_lon[1], sdt$station_lat[1], max)
}
write.table(result, "toar-6mo8hr-dma8-2008.txt",col.names=F,row.names=F,sep=" ")





############################################################
##R-INLA kriging
############################################################
#1. read data
dt = read.table("toar-6mo8hr-dma8-2008.txt",header=F,sep=" ")
names(dt)=c('ID','LON','LAT','DMA8')
dt=na.omit(dt)

#2. transform to spherical coordinates

earth.radius = 6371
lonlat3D=function(lon,lat){
  cbind(cos((lon/180)*pi)*cos((lat/180)*pi),
          sin((lon/180)*pi)*cos((lat/180)*pi),
          sin((lat/180)*pi))
}
stn_loc = lonlat3D(dt$LON, dt$LAT)



#3. triangulation of irregular monitoring network
mesh = inla.mesh.create(loc = stn_loc, cutoff = 10/earth.radius, 
	refine = list(max.edge =500/earth.radius))
#png("triangulation_obs_2008png", height =5, width =5, units ="in", res =300)
#plot(mesh, main="")
#dev.off()


#4. add non-stationary info controlled by n: the larger n represets the more complexity
basis.T=inla.mesh.basis(mesh, n=5, type="sph.harm")
basis.K=inla.mesh.basis(mesh, n=5, type="sph.harm")
spde = inla.spde2.matern(mesh, alpha=2, B.tau=cbind(0, basis.T, basis.K*0), B.kappa=cbind(0, basis.T*0, basis.K))
dt$spatial = mesh$idx$loc
formula = log(DMA8)~ -1+ f(spatial, model=spde)


#5. run MCMC
result = inla(formula, data=dt, family="gaussian", control.compute=list(cpo=TRUE, dic=TRUE), verbose=TRUE)
summary(result)

fitted.spde = result$summary.linear.predictor[,"mean"]
se=result$summary.linear.predictor[,"sd"]



#6. project results onto a desired grid
proj = inla.mesh.projector(mesh, xlim=c(-180, 179.875), ylim=c(-90, 90), dim=c(2880,1441))
msurface = inla.mesh.project(proj, result$summary.random$spatial[,"mean"]) 
ssurface = inla.mesh.project(proj, result$summary.random$spatial[,"sd"])
lat = seq(-90, by=0.125, length=1441)
lon = seq(-180, by=0.125, length=2880)
out.p = list(x=lon, y=lat, z=exp(msurface))
write.table(exp(msurface), "interpolation-mean-warm-dma8-2008.txt",col.names=F,row.names=F,sep=" ")


############################################################################################
library(maptools)
library(raster)
library(rgeos)

data(wrld_simpl)
x = out.p
r = raster(image2Grid(x))
p = as(extent(r), "SpatialPolygons")
wmap = gIntersection(wrld_simpl, p)
oceanmap = gDifference(p, wmap)

#image(r)
#plot(oceanmap, add = TRUE, col = "light blue")
#world(add=TRUE, lwd=1.5)

library(dichromat)
col2=colorschemes$DarkRedtoBlue.18
col2=c("blue 4",col2,"red 4")
##########################################################################################

png("SET1_warm_global_dma8_2008.png", height =10, width =14, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="Longitude", ylab="Latitude", horizontal=F, col=col, breaks=seq(0, 100, length.out= N+1))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
#points(cbind(dt$station_lon, dt$station_lat),lwd=1, col="white", pch=".")
mtext('(ppb)', side=3, line=0, at=200, cex=1.5)
dev.off()

out.p = list(x=lon, y=lat, z=exp(ssurface))
png("SET1_warm_global_dma8_SD_2008.png", height =10, width =14, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="Longitude", ylab="Latitude", horizontal=F, col=col, breaks=seq(0, 5, length.out= N+1))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
points(cbind(dt$station_lon, dt$station_lat),lwd=1, col="white", pch=".")
mtext("(ppb)", side=3, line=0, at=200, cex=1.5)
dev.off()
write.table(exp(ssurface), "interpolation-sd-warm-dma8-2008.txt",col.names=F,row.names=F,sep=" ")

