##Quadratic programming for regional optimal weights
##land.csv file is required for identifying the continental boundaries
##ocean is omitted
##Citation: Chang, K.-L., Cooper, O.R., West, J.J., Serre, M.L., Schultz, M.G.,
##Lin, M., Marécal, V., Josse, B., Deushi, M., Sudo, K., Liu, J., and Keller, C.A.:
##A new method (M3Fusion v1) for combining observations and multiple model output
##for an improved estimate of the global surface ozone distribution,
##Geosci. Model Dev., 2019.

col=c(rgb(0.2081, 0.1663, 0.5292),
rgb(0.3961, 0.3176, 0.8000),
rgb(0.0123, 0.4213, 0.8802),
rgb(0.4941, 0.7647, 0.8980),
rgb(0.1157, 0.7022, 0.6843),
rgb(0.5216, 0.6980, 0.1725),
rgb(0.9968, 0.7513, 0.2325),
rgb(1.0000, 0.4863, 0.0000),
rgb(0.8000, 0.3176, 0.3176),
rgb(0.6980, 0.1725, 0.1725))
N=10

library(dichromat)
col2=colorschemes$DarkRedtoBlue.18
col2=c('blue 4',col2,'red 4')
library(rworldmap)
newworld =getMap(resolution = "li")

library(fields)
library(rworldmap)
library(fields)
library(mgcv)
library(limSolve) 
library(relaimpo)


dt <- read.csv("land.csv", sep=",", header =F)
obj=list(x=seq(-179.5, by=1, length=360), y=seq(-89.5, by=1, length=180), z=matrix(dt[,3], nrow=360))
make.surface.grid( list(seq(-180, by=0.125,length=2880), seq(-90, by=0.125,length=1441)))-> loc
interp.surface(obj, loc)-> look
#image.plot(as.surface( loc, look))

dt=look
dt[dt<=0.5]=NA 
dt[dt>=0]=0 
dt=matrix(dt, nrow=2880)


######################################
#match model grid
######################################

ccmi08 = read.table("CCMI-CHASER-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-CHASER-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-CHASER-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-CHASER-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-CHASER-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-CHASER-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-CHASER-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
chaser=ccmi+dt

ccmi08 = read.table("CCMI-GFDLAM3-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-GFDLAM3-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-GFDLAM3-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-GFDLAM3-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-GFDLAM3-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-GFDLAM3-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-GFDLAM3-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
gfdlam3=ccmi+dt

ccmi08 = read.table("CCMI-GEOSCCM-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-GEOSCCM-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-GEOSCCM-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-GEOSCCM-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-GEOSCCM-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-GEOSCCM-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-GEOSCCM-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
geosccm=ccmi+dt

ccmi08 = read.table("CCMI-MOCAGE-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-MOCAGE-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-MOCAGE-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-MOCAGE-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-MOCAGE-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-MOCAGE-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-MOCAGE-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
mocage=ccmi+dt


ccmi08 = read.table("CCMI-MRIESM-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-MRIESM-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-MRIESM-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-MRIESM-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-MRIESM-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-MRIESM-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-MRIESM-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
mriesm=ccmi+dt


ccmi = read.table("GMAO-NR-dma8-2014.txt",header=F,sep=" ")
ccmi=as.matrix(ccmi)
gmaonr=ccmi+dt

spde08 = read.table("interpolation-mean-warm-dma8-2008.txt",header=F,sep=" ")
spde09 = read.table("interpolation-mean-warm-dma8-2009.txt",header=F,sep=" ")
spde10 = read.table("interpolation-mean-warm-dma8-2010.txt",header=F,sep=" ")
spde11 = read.table("interpolation-mean-warm-dma8-2011.txt",header=F,sep=" ")
spde12 = read.table("interpolation-mean-warm-dma8-2012.txt",header=F,sep=" ")
spde13 = read.table("interpolation-mean-warm-dma8-2013.txt",header=F,sep=" ")
spde14 = read.table("interpolation-mean-warm-dma8-2014.txt",header=F,sep=" ")
spde=(spde08+spde09+spde10+spde11+spde12+spde13+spde14)/7
spde=as.matrix(spde)
spde=spde+dt

lat <- rep(seq(-90, by=0.125, length=1441), each=2880)
lon <- rep(seq(-180, by=0.125, length=2880), 1441)
df2=data.frame(X=lon,Y=lat, 
	chaser=as.vector(unlist(chaser)),
	geosccm=as.vector(unlist(geosccm)),
	gfdlam3=as.vector(unlist(gfdlam3)),
	gmaonr=as.vector(unlist(gmaonr)),
	mocage=as.vector(unlist(mocage)),
	mriesm=as.vector(unlist(mriesm)),
	spde=as.vector(unlist(spde)))
#image.plot(seq(-180, by=0.125, length=2880), seq(-90, by=0.125, length=1441), chaser)
write.table(df2, "dma8_output.txt",sep = " ",row.names = F, col.names = F)



######################################
#quadratic programming 
######################################
z=df2
names(z)=c('lon','lat','chaser','geosccm','gfdlam3','gmaonr','mocage','mriesm','spde')
z=cbind(1, z)


#####AFRICA 
cy1=z[z$lon>=-20,]
cy2=cy1[cy1$lon<=35,]
cy3=cy2[cy2$lat>=10,]
cy41=cy3[cy3$lat<=37,]

cy1=z[z$lon>=-20,]
cy2=cy1[cy1$lon<=60,]
cy3=cy2[cy2$lat>=-40,]
cy42=cy3[cy3$lat<=15,]
afr=rbind(cy41, cy42)
afr=na.omit(afr)

X=as.matrix(afr[,4:9])
Y=afr[,10]
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))


#####E ASIA 
cy1=z[z$lon>=85,]
cy2=cy1[cy1$lon<=165,]
cy3=cy2[cy2$lat>=5,]
cy4=cy3[cy3$lat<=55,]

ea=na.omit(cy4)
X=as.matrix(ea[,4:9])
Y=ea[,10]
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))
 

#####S C ASIA 
cy1=z[z$lon>=25,]
cy2=cy1[cy1$lon<=95,]
cy3=cy2[cy2$lat>=5,]
cy4=cy3[cy3$lat<=55,]

sca=na.omit(cy4)
X=as.matrix(sca[,4:9])
Y=sca[,10] 
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))


#####RUSSIA
cy1=z[z$lon>=25,]
cy2=cy1[cy1$lon<=180,]
cy3=cy2[cy2$lat>=45,]
cy41=cy3[cy3$lat<=75,]
cy1=z[z$lon>=-180,]
cy2=cy1[cy1$lon<=-170,]
cy3=cy2[cy2$lat>=50,]
cy42=cy3[cy3$lat<=75,]
rus=rbind(cy41, cy42)
rus=na.omit(rus)
X=as.matrix(rus[,4:9])
Y=rus[,10]
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))


#####EUROPE 
cy1=z[z$lon>=-23,]
cy2=cy1[cy1$lon<=35,]
cy3=cy2[cy2$lat>=37,]
cy4=cy3[cy3$lat<=75,]

eur=na.omit(cy4)
X=as.matrix(eur[,4:9])
Y=eur[,10]
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))


#####OCEANIA
cy1=z[z$lon>=90,]
cy2=cy1[cy1$lon<=180,]
cy3=cy2[cy2$lat>=-50,]
cy41=cy3[cy3$lat<=10,]
cy1=z[z$lon>=-180,]
cy2=cy1[cy1$lon<=-170,]
cy3=cy2[cy2$lat>=-50,]
cy42=cy3[cy3$lat<=10,]

oce=rbind(cy41, cy42)
oce=na.omit(oce)
X=as.matrix(oce[,4:9])
Y=oce[,10] 
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))


##### N AMERICA
cy1=z[z$lon>=-168,]
cy2=cy1[cy1$lon<=-55,]
cy3=cy2[cy2$lat>=20,]
cy41=cy3[cy3$lat<=75,]
cy1=z[z$lon>=-168,]
cy2=cy1[cy1$lon<=-90,]
cy3=cy2[cy2$lat>=15,]
cy42=cy3[cy3$lat<=20,]

nam=rbind(cy41, cy42)
nam=na.omit(nam)
X=as.matrix(nam[,4:9])
Y=nam[,10]
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))


##### S AMERICA 
cy1=z[z$lon>=-90,]
cy2=cy1[cy1$lon<=-30,]
cy3=cy2[cy2$lat>=-60,]
cy4=cy3[cy3$lat<=20,]

sam=na.omit(cy4)
X=as.matrix(sam[,4:9])
Y=sam[,10]
qp=lsei(A=cbind(X, 1), B=Y, E=c(rep(1,6),0), F=1, G=rbind(cbind(diag(6),0),0), H=rep(0,7))
res1=Y-cbind(X,1)%*%qp$X
sqrt(mean(res1^2))



######################################################
###regional rmse
sqrt(mean((afr$spde-afr$chaser)^2))
sqrt(mean((afr$spde-afr$geosccm)^2))
sqrt(mean((afr$spde-afr$gfdlam3)^2))
sqrt(mean((afr$spde-afr$gmaonr)^2))
sqrt(mean((afr$spde-afr$mocage)^2))
sqrt(mean((afr$spde-afr$mriesm)^2))


sqrt(mean((ea$spde-ea$chaser)^2))
sqrt(mean((ea$spde-ea$geosccm)^2))
sqrt(mean((ea$spde-ea$gfdlam3)^2))
sqrt(mean((ea$spde-ea$gmaonr)^2))
sqrt(mean((ea$spde-ea$mocage)^2))
sqrt(mean((ea$spde-ea$mriesm)^2))


sqrt(mean((sca$spde-sca$chaser)^2))
sqrt(mean((sca$spde-sca$geosccm)^2))
sqrt(mean((sca$spde-sca$gfdlam3)^2))
sqrt(mean((sca$spde-sca$gmaonr)^2))
sqrt(mean((sca$spde-sca$mocage)^2))
sqrt(mean((sca$spde-sca$mriesm)^2))


sqrt(mean((rus$spde-rus$chaser)^2))
sqrt(mean((rus$spde-rus$geosccm)^2))
sqrt(mean((rus$spde-rus$gfdlam3)^2))
sqrt(mean((rus$spde-rus$gmaonr)^2)) 
sqrt(mean((rus$spde-rus$mocage)^2))
sqrt(mean((rus$spde-rus$mriesm)^2))


sqrt(mean((eur$spde-eur$chaser)^2))
sqrt(mean((eur$spde-eur$geosccm)^2))
sqrt(mean((eur$spde-eur$gfdlam3)^2))
sqrt(mean((eur$spde-eur$gmaonr)^2))
sqrt(mean((eur$spde-eur$mocage)^2))
sqrt(mean((eur$spde-eur$mriesm)^2))


sqrt(mean((oce$spde-oce$chaser)^2))
sqrt(mean((oce$spde-oce$geosccm)^2))
sqrt(mean((oce$spde-oce$gfdlam3)^2))
sqrt(mean((oce$spde-oce$gmaonr)^2))
sqrt(mean((oce$spde-oce$mocage)^2))
sqrt(mean((oce$spde-oce$mriesm)^2))


sqrt(mean((nam$spde-nam$chaser)^2))
sqrt(mean((nam$spde-nam$geosccm)^2))
sqrt(mean((nam$spde-nam$gfdlam3)^2))
sqrt(mean((nam$spde-nam$gmaonr)^2))
sqrt(mean((nam$spde-nam$mocage)^2))
sqrt(mean((nam$spde-nam$mriesm)^2))


sqrt(mean((sam$spde-sam$chaser)^2))
sqrt(mean((sam$spde-sam$geosccm)^2))
sqrt(mean((sam$spde-sam$gfdlam3)^2))
sqrt(mean((sam$spde-sam$gmaonr)^2))
sqrt(mean((sam$spde-sam$mocage)^2))
sqrt(mean((sam$spde-sam$mriesm)^2))




#######################################################
#regional plots Fig. 5-7
#######################################################
##GEOSCCM
ccmi08 = read.table("CCMI-GEOSCCM-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-GEOSCCM-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-GEOSCCM-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-GEOSCCM-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-GEOSCCM-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-GEOSCCM-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-GEOSCCM-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
geosccm=ccmi

spde08 = read.table("interpolation-mean-warm-dma8-2008.txt",header=F,sep=" ")
spde09 = read.table("interpolation-mean-warm-dma8-2009.txt",header=F,sep=" ")
spde10 = read.table("interpolation-mean-warm-dma8-2010.txt",header=F,sep=" ")
spde11 = read.table("interpolation-mean-warm-dma8-2011.txt",header=F,sep=" ")
spde12 = read.table("interpolation-mean-warm-dma8-2012.txt",header=F,sep=" ")
spde13 = read.table("interpolation-mean-warm-dma8-2013.txt",header=F,sep=" ")
spde14 = read.table("interpolation-mean-warm-dma8-2014.txt",header=F,sep=" ")
spde=(spde08+spde09+spde10+spde11+spde12+spde13+spde14)/7
spde=as.matrix(spde)

##CHASER
ccmi08 = read.table("CCMI-CHASER-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-CHASER-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-CHASER-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-CHASER-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-CHASER-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-CHASER-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-CHASER-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
chaser=ccmi

##MOCAGE
ccmi08 = read.table("CCMI-MOCAGE-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-MOCAGE-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-MOCAGE-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-MOCAGE-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-MOCAGE-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-MOCAGE-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-MOCAGE-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
mocage=ccmi

##MRIESM
ccmi08 = read.table("CCMI-MRIESM-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-MRIESM-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-MRIESM-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-MRIESM-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-MRIESM-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-MRIESM-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-MRIESM-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
mriesm=ccmi


##GFDLAM3
ccmi08 = read.table("CCMI-GFDLAM3-warm-dma8-2008.txt",header=F,sep=" ")
ccmi09 = read.table("CCMI-GFDLAM3-warm-dma8-2009.txt",header=F,sep=" ")
ccmi10 = read.table("CCMI-GFDLAM3-warm-dma8-2010.txt",header=F,sep=" ")
ccmi11 = read.table("CCMI-GFDLAM3-warm-dma8-2011.txt",header=F,sep=" ")
ccmi12 = read.table("CCMI-GFDLAM3-warm-dma8-2012.txt",header=F,sep=" ")
ccmi13 = read.table("CCMI-GFDLAM3-warm-dma8-2013.txt",header=F,sep=" ")
ccmi14 = read.table("CCMI-GFDLAM3-warm-dma8-2014.txt",header=F,sep=" ")
ccmi=(ccmi08+ccmi09+ccmi10+ccmi11+ccmi12+ccmi13+ccmi14)/7
ccmi=as.matrix(ccmi)
gfdlam3=ccmi

##G5NR-CHEM
ccmi = read.table("GMAO-NR-dma8-2014.txt",header=F,sep=" ")
ccmi=as.matrix(ccmi)
gmaonr=ccmi

lat = seq(-90, by=0.125, length=1441)
lon = seq(-180, by=0.125, length=2880)
out.p = list(x=lon, y=lat, z=ccmi-spde)
library(maptools)
library(raster)
library(rgeos)
data(wrld_simpl)
x = out.p
r = raster(image2Grid(x))
p = as(extent(r), "SpatialPolygons")
wmap = gIntersection(wrld_simpl, p)
oceanmap = gDifference(p, wmap)




#E ASIA  
out.p = list(x=lon, y=lat, z=spde)
png("SET1_ea_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0,100, length.out= 11), xlim=c(90,165),ylim=c(10,50))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()



dif=gfdlam3-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_gfdlam3_ea_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(90,165),ylim=c(10,50))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()


dif=chaser-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_chaser_ea_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(90,165),ylim=c(10,50))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()


dif=geosccm-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_geosccm_ea_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(90,165),ylim=c(10,50))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()


dif=gmaonr-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_gmaonr_ea_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(90,165),ylim=c(10,50))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()

dif=mocage-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_mocage_ea_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(90,165),ylim=c(10,50))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()

dif=mriesm-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_mriesm_ea_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(90,165),ylim=c(10,50))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()



dt1 = read.table("toar-6mo8hr-dma8-2008.txt",header=F,sep=" ")
dt2 = read.table("toar-6mo8hr-dma8-2009.txt",header=F,sep=" ")
dt3 = read.table("toar-6mo8hr-dma8-2010.txt",header=F,sep=" ")
dt4 = read.table("toar-6mo8hr-dma8-2011.txt",header=F,sep=" ")
dt5 = read.table("toar-6mo8hr-dma8-2012.txt",header=F,sep=" ")
dt6 = read.table("toar-6mo8hr-dma8-2013.txt",header=F,sep=" ")
dt7 = read.table("toar-6mo8hr-dma8-2014.txt",header=F,sep=" ")
dt=rbind(dt1,dt2,dt3,dt4,dt5,dt6,dt7)
dt=na.omit(dt)
colnames(dt)=c('station_id', 'station_lon', 'station_lat', 'avgdma8epax')
ea1=dt[dt$station_lon>=90,]
ea2=ea1[ea1$station_lon<=165,]
ea3=ea2[ea2$station_lat>=10,]
ea4=ea3[ea3$station_lat<=50,]

png("SET1_ea_warm_dma8_obs_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
quilt.plot(ea4$station_lon, ea4$station_lat, ea4$avgdma8epax, nx=75, ny=40, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0, 100, length.out= N+1), pch=20, xlim=c(90,165), ylim=c(10,50))
world(add=TRUE, lwd=1.5)
quilt.plot(ea4$station_lon, ea4$station_lat, ea4$avgdma8epax, nx=75, ny=40, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0, 100, length.out= N+1), pch=20, add=T, na.rm=T)
mtext('(ppb)', side=3, line=0, at=173, cex=2)
dev.off()




#N AMERICA
out.p = list(x=lon, y=lat, z=spde)
png("SET1_na_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0,100, length.out= 11), xlim=c(-168,-60),ylim=c(15,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()


dif=gfdlam3-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_gfdlam3_na_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-168,-60),ylim=c(15,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()


dif=chaser-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_chaser_na_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-168,-60),ylim=c(15,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()


dif=geosccm-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_geosccm_na_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-168,-60),ylim=c(15,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()

dif=gmaonr-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_gmaonr_na_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-168,-60),ylim=c(15,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()

dif=mocage-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_mocage_na_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-168,-60),ylim=c(15,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()

dif=mriesm-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_mriesm_na_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-168,-60),ylim=c(15,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()



dt1 = read.table("toar-6mo8hr-dma8-2008.txt",header=F,sep=" ")
dt2 = read.table("toar-6mo8hr-dma8-2009.txt",header=F,sep=" ")
dt3 = read.table("toar-6mo8hr-dma8-2010.txt",header=F,sep=" ")
dt4 = read.table("toar-6mo8hr-dma8-2011.txt",header=F,sep=" ")
dt5 = read.table("toar-6mo8hr-dma8-2012.txt",header=F,sep=" ")
dt6 = read.table("toar-6mo8hr-dma8-2013.txt",header=F,sep=" ")
dt7 = read.table("toar-6mo8hr-dma8-2014.txt",header=F,sep=" ")
dt=rbind(dt1,dt2,dt3,dt4,dt5,dt6,dt7)
dt=na.omit(dt)
colnames(dt)=c('station_id', 'station_lon', 'station_lat', 'avgdma8epax')
ea1=dt[dt$station_lon>=-168,]
ea2=ea1[ea1$station_lon<=-60,]
ea3=ea2[ea2$station_lat>=15,]
ea4=ea3[ea3$station_lat<=75,]

png("SET1_na_warm_dma8_obs_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
quilt.plot(ea4$station_lon, ea4$station_lat, ea4$avgdma8epax, nx=75, ny=40, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0, 100, length.out= N+1), pch=20, xlim=c(-168,-60),ylim=c(15,75))
world(add=TRUE, lwd=1.5)
quilt.plot(ea4$station_lon, ea4$station_lat, ea4$avgdma8epax, nx=75, ny=40, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0, 100, length.out= N+1), pch=20, add=T, na.rm=T)
mtext('(ppb)', side=3, line=0, at=-50, cex=2)
dev.off()


#Europe
out.p = list(x=lon, y=lat, z=spde)
png("SET1_eu_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0,100, length.out= 11), xlim=c(-25,30),ylim=c(37,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()



dif=gfdlam3-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_gfdlam3_eu_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-25,30),ylim=c(37,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()

dif=chaser-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_chaser_eu_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-25,30),ylim=c(37,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()

dif=geosccm-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_geosccm_eu_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-25,30),ylim=c(37,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()


dif=gmaonr-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_gmaonr_eu_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-25,30),ylim=c(37,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()

dif=mocage-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_mocage_eu_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-25,30),ylim=c(37,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()

dif=mriesm-spde
out.p = list(x=lon, y=lat, z=dif)
png("diff_mriesm_eu_warm_dma8_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
image.plot(out.p, xlab="", ylab="", horizontal=F, col=col2, breaks=seq(-50,50, length.out= 21), xlim=c(-25,30),ylim=c(37,75))
contour(out.p, drawlabels=FALSE, add=TRUE, col=24)
world(add=TRUE, lwd=1.5)
plot(oceanmap, add = TRUE, col="white")
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()



dt1 = read.table("toar-6mo8hr-dma8-2008.txt",header=F,sep=" ")
dt2 = read.table("toar-6mo8hr-dma8-2009.txt",header=F,sep=" ")
dt3 = read.table("toar-6mo8hr-dma8-2010.txt",header=F,sep=" ")
dt4 = read.table("toar-6mo8hr-dma8-2011.txt",header=F,sep=" ")
dt5 = read.table("toar-6mo8hr-dma8-2012.txt",header=F,sep=" ")
dt6 = read.table("toar-6mo8hr-dma8-2013.txt",header=F,sep=" ")
dt7 = read.table("toar-6mo8hr-dma8-2014.txt",header=F,sep=" ")
dt=rbind(dt1,dt2,dt3,dt4,dt5,dt6,dt7)
dt=na.omit(dt)
colnames(dt)=c('station_id', 'station_lon', 'station_lat', 'avgdma8epax')
ea1=dt[dt$station_lon>=-25,]
ea2=ea1[ea1$station_lon<=30,]
ea3=ea2[ea2$station_lat>=37,]
ea4=ea3[ea3$station_lat<=75,]

png("SET1_eu_warm_dma8_obs_2008-14.png", height =7, width =7, units ="in", res =300)
par(mar=c(3.5, 3.5, 2, 1), mgp=c(2.4, 0.8, 0), las=1)
quilt.plot(ea4$station_lon, ea4$station_lat, ea4$avgdma8epax, nx=75, ny=40, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0, 100, length.out= N+1), pch=20, xlim=c(-25,30),ylim=c(37,75))
world(add=TRUE, lwd=1.5)
quilt.plot(ea4$station_lon, ea4$station_lat, ea4$avgdma8epax, nx=75, ny=40, xlab="", ylab="", horizontal=F, col=col, breaks=seq(0, 100, length.out= N+1), pch=20, add=T, na.rm=T)
mtext('(ppb)', side=3, line=0, at=35, cex=2)
dev.off()


